@@ -153,6 +153,9 @@ bool validPixmaps( TQPixmap* p[] )
 
 ThemeHandler::ThemeHandler()
 {
+	TDEGlobal::locale()->insertCatalogue("twin_clients");
+	TDEGlobal::locale()->insertCatalogue("twin_art_clients");
+
 	initialized = false;
 
 	// Prevent having globals objects (use pointers to objects)
