@@ -35,6 +35,7 @@
 #include <tqpixmap.h>
 
 #include <tdeapplication.h>
+#include <tdeglobal.h>
 #include <tdelocale.h>
 
 #include "OpenLook.h"
@@ -55,6 +56,8 @@ static uint titleHeight;
 
 DecorationFactory::DecorationFactory()
 {
+	TDEGlobal::locale()->insertCatalogue("twin_clients");
+	TDEGlobal::locale()->insertCatalogue("twin_art_clients");
 }
 
 DecorationFactory::~DecorationFactory()
@@ -725,4 +728,3 @@ OpenLook::isButtonRelease(TQMouseEvent * e)
 }
 
 #include "OpenLook.moc"
-// vim:ts=2:sw=2:tw=78:set et:
