@@ -9,6 +9,7 @@
 
 #include <kpixmapeffect.h>
 #include <kdrawutil.h>
+#include <tdeglobal.h>
 #include <tdelocale.h>
 #include <tdeapplication.h>
 #include <kdebug.h>
@@ -684,6 +685,8 @@ void SystemClient::borders(int& left, int& right, int& top, int& bottom) const
 
 SystemDecoFactory::SystemDecoFactory()
 {
+   TDEGlobal::locale()->insertCatalogue("twin_clients");
+   TDEGlobal::locale()->insertCatalogue("twin_art_clients");
    create_pixmaps();
 }
 
